﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Media;
using System.Windows.Media.Animation;
using Telerik.Windows.Controls;

namespace WpfApplication1
{
    public class RibbonUtilities
    {
        public static readonly DependencyProperty BackstageAnimationProperty = DependencyProperty.RegisterAttached(
           "RibbonBackstageAnimation",
           typeof(BackstageAnimation),
           typeof(RibbonUtilities),
           new PropertyMetadata(BackstageAnimation.None, RibbonBackstageAnimationChanged));

        public static readonly DependencyProperty RibbonViewWidthProperty = DependencyProperty.RegisterAttached(
            "RibbonViewWidth",
            typeof(double),
            typeof(RibbonUtilities),
            new PropertyMetadata(300d));

        public static double GetRibbonViewWidthProperty(DependencyObject obj)
        {
            return (double)obj.GetValue(RibbonViewWidthProperty);
        }

        public static void SetRibbonViewWidthProperty(DependencyObject obj, double value)
        {
            obj.SetValue(RibbonViewWidthProperty, value);
        }

        public static BackstageAnimation GeBackstageAnimation(DependencyObject obj)
        {
            return (BackstageAnimation)obj.GetValue(BackstageAnimationProperty);
        }

        public static void SetBackstageAnimation(DependencyObject obj, BackstageAnimation value)
        {
            obj.SetValue(BackstageAnimationProperty, value);
        }

        private static void RibbonBackstageAnimationChanged(DependencyObject target, DependencyPropertyChangedEventArgs args)
        {
            RadRibbonBackstage backstage = (RadRibbonBackstage)target;
            backstage.HorizontalAlignment = HorizontalAlignment.Left;

            if ((BackstageAnimation)args.NewValue == BackstageAnimation.SlideLeftToRigth)
            {
                backstage.Loaded += Backstage_Loaded;
            }
        }

        private const int ANIMATION_DURATION_MILISECONDS = 100;
        private static Duration AnimationDuration = new Duration(TimeSpan.FromMilliseconds(ANIMATION_DURATION_MILISECONDS));

        private static void Backstage_Loaded(object sender, RoutedEventArgs e)
        {
            RadRibbonBackstage backstage = (RadRibbonBackstage)sender;

            var newWidth = RibbonUtilities.GetRibbonViewWidthProperty(backstage);
            DoubleAnimation animation = new DoubleAnimation();
            animation.From = 0;
            animation.To = newWidth;
            animation.Duration = AnimationDuration;

            Storyboard.SetTarget(animation, backstage);
            Storyboard.SetTargetProperty(animation, new PropertyPath(RadRibbonBackstage.WidthProperty));

            Storyboard storyboard = new Storyboard();
            storyboard.Children.Add(animation);
            storyboard.Begin();
        }
    }
}
